@@ -51,7 +51,22 @@ class GroupAPIView(APIView):
 
     def group_user_list(self):
         group_id = self.GET.get("group_id", None)
-        data, err = GroupService.group_user_list(group_id)
+        page = self.GET.get("page", 1)
+        size = self.GET.get("size", 10)
+        data, err = GroupService.group_user_list(group_id, page, size)
+        if err:
+            return util_response(err=2000, msg=err)
+        return util_response(data=data)
+
+    def group_user_detail(self):
+        user_id = self.GET.get("user_id", None)
+        data, err = GroupService.group_user_detail(user_id)
+        if err:
+            return util_response(err=2000, msg=err)
+        return util_response(data=data)
+
+    def group_user_add(self):
+        data, err = GroupService.group_user_add(self.POST)
         if err:
             return util_response(err=2000, msg=err)
         return util_response(data=data)
@@ -65,7 +80,7 @@ class GroupAPIView(APIView):
         return util_response(data=data)
 
     def put(self, request, **kwargs):
-        # 用户组 添加接口
+        # 用户组 修改接口
         params = parse_data(request)
         params.setdefault("id", kwargs.get("user_group_id", None))
         data, err = GroupService.edit_group(params)
@@ -74,7 +89,7 @@ class GroupAPIView(APIView):
         return util_response(data=data)
 
     def post(self, request, **kwargs):
-        # 用户组 修改接口
+        # 用户组 添加接口
         params = parse_data(request)
         data, err = GroupService.add_group(params)
         if err:
@@ -91,18 +106,11 @@ class GroupAPIView(APIView):
             return util_response(err=1001, msg=err)
         return util_response(data=data)
 
-    def bind_user_role(self, **kwargs):
-        # 用户组 修改接口
-        params = self.POST
-        data, err = GroupService.bind_user_role(params)
-        if err:
-            return util_response(err=1000, msg=err)
-        return util_response(data=data)
-
     def bind_user_group(self, **kwargs):
         # 用户组 修改接口
-        params = self.POST
-        data, err = GroupService.bind_user_group(params)
+        user_id = self.POST.get("user_id", None)
+        group_list = self.POST.get("group_list", None)
+        data, err = GroupService.bind_user_group(user_id, group_list)
         if err:
             return util_response(err=1000, msg=err)
         return util_response(data=data)
