@@ -14,6 +14,7 @@ from django.forms.models import model_to_dict
 from xj_role.services.role_service import RoleService
 from xj_user.models import BaseInfo
 from xj_user.services.user_service import UserService
+from xj_user.services.user_detail_info_service import DetailInfoService
 from ..models import UserToGroup, RoleUserGroup, UserToRole
 from ..utils.model_handle import format_params_handle, parse_json
 
@@ -149,7 +150,7 @@ class GroupService(object):
         return parse_tree(parse_json(tree_data), 0), None
 
     @staticmethod
-    def group_user_list(group_id, page=1, size=10):
+    def group_user_list(group_id, page, size):
 
         user_set = UserToGroup.objects.filter(user_group=group_id).annotate(
             user_group_value=F("user_group__group_name"))
@@ -157,20 +158,56 @@ class GroupService(object):
             "user_id",
             "user_group",
         )
-        user_dict = {}
-        for it in user_set:
-            if str(it['user_id']) not in user_dict:
-                user_dict[str(it['user_id'])] = []
-            user_dict[str(it['user_id'])].append(it['user_group'])
+        params = {
+            "page": page,
+            "size": size
+        }
+        # TODO 这样的逻辑 返回的用户组列表 无法显示全部 。解决方案一：在详情的时候处理用户所在的组 方案二：通过聚合表 拿到用户的组
+        # user_dict = {}
+        # for it in user_set:
+        #     if str(it['user_id']) not in user_dict:
+        #         user_dict[str(it['user_id'])] = []
+        #     user_dict[str(it['user_id'])].append(it['user_group'])
         user_id_list = [it['user_id'] for it in user_set]
-        user_serv, err = UserService.user_list(allow_user_list=user_id_list)
+        user_serv, err = UserService.user_list(params, allow_user_list=user_id_list)
         if err:
             return None, err
-        user_list = user_serv['list']
-        for it in user_list:
-            if str(it['user_id']) in user_dict:
-                it['user_group_list'] = user_dict[str(it['user_id'])]
-        return user_list, None
+        # for it in user_list:
+        #     if str(it['user_id']) in user_dict:
+        #         it['user_group_list'] = user_dict[str(it['user_id'])]
+        return user_serv, None
+
+    @staticmethod
+    def group_user_detail(user_id):
+        user_serv, err = DetailInfoService.get_detail(user_id)
+        user_group_serv = UserToGroup.objects.filter(user_id=user_id).values("user_id", 'user_group_id')
+        user_group_dict = {item['user_group_id'] for item in user_group_serv}
+        user_role_serv = UserToRole.objects.filter(user_id=user_id).values("user_id", 'role_id')
+        user_role_dict = {item['role_id'] for item in user_role_serv}
+        user_serv['user_group_list'] = list(user_group_dict)
+        user_serv['user_role_list'] = list(user_role_dict)
+        if err:
+            return None, err
+        return user_serv, None
+
+    @staticmethod
+    def group_user_add(params):
+        # 用户角色部门绑定
+        user_role_list = params.get('user_role_list', None)
+        user_group_list = params.get('user_group_list', None)
+        user_serv, err = UserService.user_add(params)
+        if err:
+            return None, err
+        if user_group_list:
+            GroupService.bind_user_group(user_serv['user_id'], user_group_list)
+
+        if user_role_list:
+            RoleService.bind_user_role(user_serv['user_id'], user_role_list)
+        return user_serv, None
+
+    @staticmethod
+    def group_user_delete(params):
+        return None, None
 
     @staticmethod
     def user_bind_group(user_id, group_id):
@@ -187,6 +224,21 @@ class GroupService(object):
         except Exception as e:
             return None, str(e)
 
+    @staticmethod
+    def bind_user_group(user_id, group_list):
+        list = group_list.split(',')
+        UserToGroup.objects.filter(user_id=user_id).delete()
+        try:
+            for i in list:
+                data = {
+                    "user_id": user_id,
+                    "user_group_id": i
+                }
+                UserToGroup.objects.create(**data)
+            return None, None
+        except Exception as e:
+            return None, str(e)
+
     @staticmethod
     def group_list(params):
         params = format_params_handle(
@@ -209,7 +261,7 @@ class GroupService(object):
         if not params:
             return None, "参数不能为空"
         instance = RoleUserGroup.objects.create(**params)
-        return {"id": instance.id}, None
+        return None, None
 
     @staticmethod
     def edit_group(params):
@@ -233,49 +285,3 @@ class GroupService(object):
         if instance:
             instance.delete()
         return None, None
-
-    @staticmethod
-    def bind_user_role(params):
-        params = format_params_handle(param_dict=params, filter_filed_list=[
-            "user_id",
-            "role_list"
-        ])
-        if not params:
-            return None, "参数不能为空"
-        id = params['user_id']
-        role = params['role_list']
-        try:
-            for i in role.split(','):
-                res = UserToRole.objects.filter(user_id=id, role_id=i).exists()
-                if not res:
-                    data = {
-                        "user_id": id,
-                        "role_id": i
-                    }
-                    instance = UserToRole.objects.create(**data)
-            return None, None
-        except Exception as e:
-            return None, str(e)
-
-    @staticmethod
-    def bind_user_group(params):
-        params = format_params_handle(param_dict=params, filter_filed_list=[
-            "user_id",
-            "group_list"
-        ])
-        if not params:
-            return None, "参数不能为空"
-        id = params['user_id']
-        role = params['group_list']
-        try:
-            for i in role.split(','):
-                res = UserToGroup.objects.filter(user_id=id, user_group_id=i).exists()
-                if not res:
-                    data = {
-                        "user_id": id,
-                        "user_group_id": i
-                    }
-                    instance = UserToGroup.objects.create(**data)
-            return None, None
-        except Exception as e:
-            return None, str(e)
