@@ -87,7 +87,7 @@ class RoleService:
 
     @staticmethod
     def user_bind_role(user_id, role_id):
-        # 用户绑定部门
+        # 用户绑定角色
         if not user_id or not role_id:
             return None, "参数错误，user_id, role_id 必传"
         try:
@@ -99,3 +99,52 @@ class RoleService:
             return None, None
         except Exception as e:
             return None, str(e)
+
+    @staticmethod
+    def bind_user_role(user_id, role_list):
+        list = role_list.split(',')
+        UserToRole.objects.filter(user_id=user_id).delete()
+        try:
+            for i in list:
+                data = {
+                    "user_id": user_id,
+                    "role_id": i
+                }
+                UserToRole.objects.create(**data)
+            return None, None
+        except Exception as e:
+            return None, str(e)
+
+    @staticmethod
+    def add_role(params):
+        params = format_params_handle(param_dict=params,
+                                      filter_filed_list=["role", "role_name", "parent_role_id", "permission_id",
+                                                         "user_group_id", "description"])
+        if not params:
+            return None, "参数不能为空"
+        instance = Role.objects.create(**params)
+        return {"id": instance.id}, None
+
+    @staticmethod
+    def edit_role(params):
+        params = format_params_handle(param_dict=params,
+                                      filter_filed_list=["role_id", "role", "role_name", "parent_role_id", "permission_id",
+                                                         "user_group_id", "description"])
+        id = params.pop("role_id", None)
+        if not id:
+            return None, "ID 不可以为空"
+        if not params:
+            return None, "没有可以修改的字段"
+        instance = Role.objects.filter(id=id)
+        if params:
+            instance.update(**params)
+        return None, None
+
+    @staticmethod
+    def del_role(id):
+        if not id:
+            return None, "ID 不可以为空"
+        instance = Role.objects.filter(id=id)
+        if instance:
+            instance.delete()
+        return None, None
